summaryrefslogtreecommitdiffstats
path: root/config.def.h
diff options
context:
space:
mode:
Diffstat (limited to 'config.def.h')
-rw-r--r--config.def.h10
1 files changed, 8 insertions, 2 deletions
diff --git a/config.def.h b/config.def.h
index 9f6f41e..54d0c54 100644
--- a/config.def.h
+++ b/config.def.h
@@ -29,13 +29,16 @@ static const unsigned int alphas[][3] = {
static const char *tags[] = { "1", "2", "3", "4", "5", "6", "7", "8", "9", "0" };
static const char *tagfmt = "[%s: %.30s]";
+static const char *scratchpad_size = "120x34";
static const Rule rules[] = {
/* xprop(1):
* WM_CLASS(STRING) = instance, class
* WM_NAME(STRING) = title
*/
- /* class instance title tags mask isfloating monitor */
- { NULL, NULL, NULL, 0, 0, -1 },
+ /* class instance title tags mask isfloating monitor scratchpad exec */
+ { "st", "sp-shell", NULL, SPTAG(0), 1, -1, NULL },
+ { "st", "sp-pythn", NULL, SPTAG(1), 1, -1, "ipython3" },
+ { "st", "sp-mixer", NULL, SPTAG(2), 1, -1, "alsamixer" },
};
/* layout(s) */
@@ -113,6 +116,9 @@ static const Key keys[] = {
{ MODKEY, XK_period, focusmon, {.i = +1 } },
{ MODKEY|ShiftMask, XK_comma, tagmon, {.i = -1 } },
{ MODKEY|ShiftMask, XK_period, tagmon, {.i = +1 } },
+ { MODKEY, XK_grave, togglescratch, {.v = &rules[0]} },
+ { MODKEY, XK_equal, togglescratch, {.v = &rules[1]} },
+ { MODKEY, XK_minus, togglescratch, {.v = &rules[2]} },
TAGKEYS( XK_1, 0)
TAGKEYS( XK_2, 1)
TAGKEYS( XK_3, 2)